==> nextcloud-14.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/sv.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Redigera kommentar",
    "Delete comment" : "Radera kommentar",
    "New comment …" : "Ny kommentar ...",
    "Post" : "Skicka",
    "Cancel" : "Avbryt",
    "[Deleted user]" : "[Raderad användare]",
    "Comments" : "Kommentarer",
    "No comments yet, start the conversation!" : "Inga kommentarer ännu.",
    "More comments …" : "Fler kommentarer ...",
    "Save" : "Spara",
    "Allowed characters {count} of {max}" : "Antal tillåtna tecken, {count} av {max}",
    "Error occurred while retrieving comment with ID {id}" : "Fel uppstod när kommentaren med ID {id} hämtades",
    "Error occurred while updating comment with id {id}" : "Fel inträffade vid uppdatering av kommentar med id {id}",
    "Error occurred while posting comment" : "Fel inträffade vid publicering av kommentar",
    "_%n unread comment_::_%n unread comments_" : ["%n oläst kommentar","%n olästa kommentarer"],
    "Comment" : "Kommentar",
    "You commented" : "Du kommenterade",
    "%1$s commented" : "%1$s kommenterade",
    "{author} commented" : "{author} kommenterade",
    "You commented on %1$s" : "Du kommenterade på %1$s",
    "You commented on {file}" : "Du kommenterade på {file}",
    "%1$s commented on %2$s" : "%1$s kommenterade på %2$s",
    "{author} commented on {file}" : "{author} kommenterade på {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentarer</strong> för filer",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Du nämndes på “%s” i en kommentar av en användare som nu har tagits bort",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Du nämndes på “{file}” i en kommentar av en användare som nu har tagits bort",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s nämnde dig i en kommentar på “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} nämnde dig i en kommentar på \"{file}\"",
    "Unknown user" : "Okänd användare",
    "A (now) deleted user mentioned you in a comment on “%s”" : "En (nu) raderad användare nämnde dig i en kommentar på \"%s\"",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "En (nu) raderad användare nämnde dig i en kommentar på \"{file}\""
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/sv.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Redigera kommentar",
    "Delete comment" : "Radera kommentar",
    "New comment …" : "Ny kommentar ...",
    "Post" : "Skicka",
    "Cancel" : "Avbryt",
    "[Deleted user]" : "[Raderad användare]",
    "Comments" : "Kommentarer",
    "No comments yet, start the conversation!" : "Inga kommentarer ännu.",
    "More comments …" : "Fler kommentarer ...",
    "Save" : "Spara",
    "Allowed characters {count} of {max}" : "Antal tillåtna tecken, {count} av {max}",
    "Error occurred while retrieving comment with ID {id}" : "Fel uppstod när kommentaren med ID {id} hämtades",
    "Error occurred while updating comment with id {id}" : "Fel inträffade vid uppdatering av kommentar med id {id}",
    "Error occurred while posting comment" : "Fel inträffade vid publicering av kommentar",
    "_%n unread comment_::_%n unread comments_" : ["%n oläst kommentar","%n olästa kommentarer"],
    "Comment" : "Kommentar",
    "You commented" : "Du kommenterade",
    "%1$s commented" : "%1$s kommenterade",
    "{author} commented" : "{author} kommenterade",
    "You commented on %1$s" : "Du kommenterade på %1$s",
    "You commented on {file}" : "Du kommenterade på {file}",
    "%1$s commented on %2$s" : "%1$s kommenterade på %2$s",
    "{author} commented on {file}" : "{author} kommenterade på {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentarer</strong> för filer",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Du nämndes på “{file}” i en kommentar av en användare som nu har tagits bort",
    "{user} mentioned you in a comment on “{file}”" : "{user} nämnde dig i en kommentar på \"{file}\"",
    "Unknown user" : "Okänd användare",
    "A (now) deleted user mentioned you in a comment on “%s”" : "En (nu) raderad användare nämnde dig i en kommentar på \"%s\"",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "En (nu) raderad användare nämnde dig i en kommentar på \"{file}\"",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s nämnde dig i en kommentar på “%2$s”",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Du nämndes på “%s” i en kommentar av en användare som nu har tagits bort"
},
"nplurals=2; plural=(n != 1);");
